Module handle

Module handle 

Blocking handle for Rhai to communicate with RPC client

This handle provides simple blocking methods that Rhai functions can call. Each method sends a command to an async thread and blocks waiting for the response.

Structs

ZinitHandle
Synchronous handle for Rhai functions to use