pub struct LifecycleDef {
pub restart: RestartPolicy,
pub restart_delay_ms: u64,
pub restart_delay_max_ms: u64,
pub max_restarts: u32,
pub stability_period_ms: u64,
pub start_timeout_ms: u64,
pub stop_timeout_ms: u64,
pub stop_signal: String,
}Expand description
Lifecycle configuration section.
Fields
restart: RestartPolicyrestart_delay_ms: u64Initial restart delay in milliseconds (doubles each restart for exponential backoff).
restart_delay_max_ms: u64Maximum restart delay in milliseconds (cap for exponential backoff).
max_restarts: u32Maximum number of restart attempts (0 = unlimited).
stability_period_ms: u64How long a service must run before backoff counter is reset (milliseconds). If a service crashes before this period, backoff continues to increase.
start_timeout_ms: u64stop_timeout_ms: u64stop_signal: StringTrait Implementations
Sourceimpl Clone for LifecycleDef
impl Clone for LifecycleDef
Sourcefn clone(&self) -> LifecycleDef
fn clone(&self) -> LifecycleDef
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LifecycleDef
impl Debug for LifecycleDef
Sourceimpl Default for LifecycleDef
impl Default for LifecycleDef
Sourceimpl<'de> Deserialize<'de> for LifecycleDef
impl<'de> Deserialize<'de> for LifecycleDef
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for LifecycleDef
impl PartialEq for LifecycleDef
Sourceimpl Serialize for LifecycleDef
impl Serialize for LifecycleDef
impl StructuralPartialEq for LifecycleDef