pub enum ServiceState {
Inactive,
Blocked {
waiting_on: Vec<String>,
},
Starting {
pid: u32,
},
Running {
pid: u32,
},
Stopping {
pid: u32,
},
Exited {
exit_code: Option<i32>,
},
Failed {
reason: FailureReason,
},
}Expand description
The state of a service in the supervisor.
Variants
Inactive
Service has never been started.
Blocked
Service is waiting on dependencies.
Starting
Process has been spawned, waiting for health check or startup.
Running
Process is running and healthy.
Stopping
SIGTERM sent, waiting for process to exit.
Exited
Process exited cleanly.
Failed
Process failed.
Fields

reason: FailureReasonImplementations
Sourceimpl ServiceState
impl ServiceState
Sourcepub fn is_satisfied(&self) -> bool
pub fn is_satisfied(&self) -> bool
Returns true if the service can satisfy a “requires” dependency. A service satisfies requires if it’s Running OR exited successfully (exit code 0). This allows oneshot services to satisfy dependencies after they complete.
Sourcepub fn can_attempt_start(&self) -> bool
pub fn can_attempt_start(&self) -> bool
Returns true if the service is in a state where start can be attempted. Note: Services that failed due to MissingDependency cannot be restarted because the dependency will never appear - it’s a permanent config error.